# NOMAD-CAMELS Driver for Agilent 34401A

Driver of the Agilent 34401A digital multimeter written for the measurement software [NOMAD-CAMELS](https://fau-lap.github.io/NOMAD-CAMELS/).


## Documentation

For more information and documentation visit [this page](https://fau-lap.github.io/NOMAD-CAMELS/docs/instruments.html).